[![Python application](https://github.com/wwu-mmll/photonai_conformal/actions/workflows/lindandtest.yml/badge.svg)](https://github.com/wwu-mmll/photonai_conformal/actions/workflows/lindandtest.yml)
[![Coverage Status](https://coveralls.io/repos/github/wwu-mmll/photonai_conformal/badge.svg?branch=main&t=cFq2Sq)](https://coveralls.io/github/wwu-mmll/photonai_conformal?branch=main)
[![Quality Gate Status](https://sonarcloud.io/api/project_badges/measure?project=wwu-mmll_photonai_conformal&metric=alert_status)](https://sonarcloud.io/summary/new_code?id=wwu-mmll_photonai_conformal)
![GitHub](https://img.shields.io/github/license/wwu-mmll/photonai_conformal)
[![Twitter URL](https://img.shields.io/twitter/url?style=social&url=https%3A%2F%2Ftwitter.com%2Fwwu_mmll)](https://twitter.com/wwu_mmll)
# photonai_conformal
PHOTONAI conformal enables simple usage of conformal predictions in photonai based on [mapie](https://mapie.readthedocs.io/en/latest/index.html).

## Project Setup
Install the latest version with pip
```
pip install git+https://github.com/wwu-mmll/photonai_conformal
```

## Features
- [X] Basic conformal predictions for photonai
- [ ] Compatibility of PipelineElement for Mapie